icsemantic.catalog.indexes

Package platecom :: Package ontocatalog :: Package indexes |
[hide private]
[frames] | no frames]

# Package indexes

source code

This package implements three new indexes for the portal catalog.

Those indexes are: SynonymIndex, RelatedIndex and TranslationIndex.

Submodules | [hide private]
icsemantic.catalog.indexes.related: RelatedIndex is an index for the catalog that does not index anything. icsemantic.catalog.indexes.synonym: SynonymIndex is an index for the catalog that does not index anything. icsemantic.catalog.indexes.translation: TranslationIndex is an index for the catalog that does not index anything. icsemantic.catalog.indexes.utils: A few common pieces of code used in the catalog indexes in this package are grouped into functions in this module to make its reuse easier.